@@ -1535,6 +1535,15 @@ class VariableClUpdateOutdatedKernelSet(ReadonlyVariable):
         ui = UpdateInfo(self.parent)
         return "on" if ui.outdated_kernel else "off"
 
+class VariableClUpdateAvailableSet(ReadonlyVariable):
+    """
+    Есть обновления
+    """
+    type = "bool"
+
+    def get(self):
+        ui = UpdateInfo(self.parent)
+        return "on" if ui.need_update() else "off"
 
 class VariableClUpdateBinhostList(Variable):
     """
